@@ -18,27 +18,33 @@ type Config struct {
 	Context *Context `yaml:"k9s"`
 }
 
+// NewConfig returns a new config.
 func NewConfig(ct *api.Context) *Config {
 	return &Config{
 		Context: NewContextFromConfig(ct),
 	}
 }
 
+// Validate ensures config is in norms.
 func (c *Config) Validate(conn client.Connection, ks KubeSettings) {
+	if c.Context == nil {
+		c.Context = NewContext()
+	}
 	c.Context.Validate(conn, ks)
 }
 
+// Dump used for debugging.
 func (c *Config) Dump(w io.Writer) {
 	bb, _ := yaml.Marshal(&c)
 
 	fmt.Fprintf(w, "%s\n", string(bb))
 }
 
+// Save saves the config to disk.
 func (c *Config) Save(path string) error {
 	if err := EnsureDirPath(path, DefaultDirMod); err != nil {
 		return err
 	}
-
 	cfg, err := yaml.Marshal(c)
 	if err != nil {
 		return err
