@@ -10,6 +10,9 @@ import (
 	"path/filepath"
 	"strings"
 
+	"github.com/derailed/k9s/internal/config/data"
+	"github.com/derailed/k9s/internal/config/json"
+
 	"github.com/adrg/xdg"
 	"gopkg.in/yaml.v2"
 )
@@ -47,6 +50,7 @@ func NewPlugins() Plugins {
 // Load K9s plugins.
 func (p Plugins) Load(path string) error {
 	var errs error
+
 	if err := p.load(AppPluginsFile); err != nil {
 		errs = errors.Join(errs, err)
 	}
@@ -74,12 +78,12 @@ func (p Plugins) loadPluginDir(dir string) error {
 		if file.IsDir() || !isYamlFile(file.Name()) {
 			continue
 		}
-		pluginFile, err := os.ReadFile(filepath.Join(dir, file.Name()))
+		bb, err := os.ReadFile(filepath.Join(dir, file.Name()))
 		if err != nil {
 			errs = errors.Join(errs, err)
 		}
 		var plugin Plugin
-		if err = yaml.Unmarshal(pluginFile, &plugin); err != nil {
+		if err = yaml.Unmarshal(bb, &plugin); err != nil {
 			return err
 		}
 		p.Plugins[strings.TrimSuffix(file.Name(), filepath.Ext(file.Name()))] = plugin
@@ -92,13 +96,15 @@ func (p *Plugins) load(path string) error {
 	if _, err := os.Stat(path); os.IsNotExist(err) {
 		return nil
 	}
-	f, err := os.ReadFile(path)
+	bb, err := os.ReadFile(path)
 	if err != nil {
 		return err
 	}
-
+	if err := data.JSONValidator.Validate(json.PluginsSchema, bb); err != nil {
+		return fmt.Errorf("validation failed for %q: %w", path, err)
+	}
 	var pp Plugins
-	if err := yaml.Unmarshal(f, &pp); err != nil {
+	if err := yaml.Unmarshal(bb, &pp); err != nil {
 		return err
 	}
 	for k, v := range pp.Plugins {
