@@ -68,9 +68,9 @@ func (p *Popeye) List(ctx context.Context, ns string) ([]runtime.Object, error)
 		flags.Sections = &sections
 		flags.ActiveNamespace = &ns
 	}
-	spinach := cfg.YamlExtension(filepath.Join(cfg.K9sHome(), "spinach.yaml"))
+	spinach := filepath.Join(cfg.AppConfigDir, "spinach.yaml")
 	if c, err := p.GetFactory().Client().Config().CurrentContextName(); err == nil {
-		spinach = cfg.YamlExtension(filepath.Join(cfg.K9sHome(), fmt.Sprintf("%s_spinach.yaml", c)))
+		spinach = filepath.Join(cfg.AppConfigDir, fmt.Sprintf("%s_spinach.yaml", c))
 	}
 	if _, err := os.Stat(spinach); err == nil {
 		flags.Spinach = &spinach
