@@ -108,7 +108,7 @@ func TestAsKey(t *testing.T) {
 		e   tcell.Key
 	}{
 		"cool": {k: "Ctrl-A", e: tcell.KeyCtrlA},
-		"miss": {k: "fred", e: 0, err: errors.New("no matching key found fred")},
+		"miss": {k: "fred", e: 0, err: errors.New(`invalid key specified: "fred"`)},
 	}
 
 	for k := range uu {
@@ -157,7 +157,7 @@ func TestK9sEnv(t *testing.T) {
 	r := render.Row{
 		Fields: []string{"a1", "b1", "c1"},
 	}
-	env := defaultEnv(c, "fred/blee", h, r)
+	env := defaultEnv(c, "fred/blee", h, &r)
 
 	assert.Equal(t, 10, len(env))
 	assert.Equal(t, cl, env["CLUSTER"])
